RESTfly
=======

.. image:: docs/_static/logo.png

.. image:: https://travis-ci.org/SteveMcGrath/restfly.svg?branch=master
   :target: https://travis-ci.org/SteveMcGrath/restfly
.. image:: https://img.shields.io/pypi/v/restfly.svg
   :target: https://pypi.org/project/restfly/
.. image:: https://img.shields.io/pypi/pyversions/restfly.svg
   :target: https://pypi.org/project/restfly/
.. image:: https://img.shields.io/pypi/dm/restfly.svg
   :target: https://github.com/stevemcgrath/restfly
.. image:: https://img.shields.io/github/license/stevemcgrath/restfly.svg
   :target: https://github.com/stevemcgrath/restfly

A simple framework for building RESTful API libraries.  for more information,
please refer to the documentation at https://restfly.readthedocs.io